/**
 * @license
 * Copyright 2021 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */
/// <amd-module name="@tensorflow/tfjs-tflite/dist/tflite_task_library_client/bert_qa" />
import { BertQuestionAnswerer as TaskLibraryBertQuestionAnswerer } from '../types/bert_qa';
import { BaseTaskLibraryClient } from './common';
/** A single answer. */
export interface QaAnswer {
    /** The text of the answer. */
    text: string;
    /** The position and logit of the answer. */
    pos: Pos;
}
/** Answer position. */
export interface Pos {
    /** The start position. */
    start: number;
    /** The end position. */
    end: number;
    /** The logit. */
    logit: number;
}
/**
 * Client for BertQA TFLite Task Library.
 *
 * It is a wrapper around the underlying javascript API to make it more
 * convenient to use. See comments in the corresponding type declaration file in
 * src/types for more info.
 */
export declare class BertQuestionAnswerer extends BaseTaskLibraryClient {
    protected instance: TaskLibraryBertQuestionAnswerer;
    constructor(instance: TaskLibraryBertQuestionAnswerer);
    static create(model: string | ArrayBuffer): Promise<BertQuestionAnswerer>;
    answer(context: string, question: string): QaAnswer[];
}
